@@ -18,13 +18,16 @@
 #'
 #' #Create a list of populations and merge list
 #' pop = newPop(founderPop, simParam=SP)
+#' pop@misc$tmp = rnorm(n=10)
+#' pop@misc$tmp2 = rnorm(n=10)
+#'
 #' popList = list(pop, pop)
 #' pop2 = mergePops(popList)
 #'
 #' @export
 mergePops = function(popList){
   if(is(popList,"MultiPop")){
-    for(i in 1:length(popList@pops)){
+    for(i in seq_len(length(popList@pops))){
       if(is(popList@pops[i],"MultiPop")){
         popList@pops[i] = mergePops(popList@pops[i])
       }
@@ -40,16 +43,19 @@ mergePops = function(popList){
     classes = classes[-remove]
   }
   stopifnot(all(classes=="Pop"))
+  
   #nChr
   nChr = do.call("c",lapply(popList,
                             function(x) x@nChr))
   stopifnot(all(nChr==nChr[1]))
   nChr = nChr[1]
+  
   #ploidy
   ploidy = do.call("c",lapply(popList,
                               function(x) x@ploidy))
   stopifnot(all(ploidy==ploidy[1]))
   ploidy = ploidy[1]
+  
   #nLoci
   nLoci = do.call("c",lapply(popList,
                              function(x){
@@ -57,50 +63,82 @@ mergePops = function(popList){
                              }))
   stopifnot(all(nLoci))
   nLoci = popList[[1]]@nLoci
+  
   #id
   id = do.call("c",
                lapply(popList,
                       function(x) x@id))
+  
   #iid
   iid = do.call("c",
                 lapply(popList,
                        function(x) x@iid))
+  
   #mother
   mother = do.call("c",
                    lapply(popList,
                           function(x) x@mother))
+  
   #father
   father= do.call("c",
                   lapply(popList,
                          function(x) x@father))
+  
   #fixEff
   fixEff= do.call("c",
                   lapply(popList,
                          function(x) x@fixEff))
-
+  
   #misc
-  misc = do.call("c",
-                 lapply(popList,
-                        function(x) x@misc))
-
+  tmp = sapply(popList, function(x) length(x@misc))
+  if(all(tmp == tmp[1]) & tmp[1]>0) {
+    tmp = lapply(popList, function(x) names(x@misc))
+    allMatch = TRUE
+    if(length(tmp)>1){
+      for(i in 2:length(tmp)){
+        if(!all(tmp[[1]]==tmp[[i]])){
+          allMatch = FALSE
+          break
+        }
+      }
+    }
+    if(allMatch){
+      misc = vector("list", length=length(tmp[[1]]))
+      for(i in seq_len(length(tmp[[1]]))){
+        miscTmp = lapply(popList, function(x) x@misc[[i]])
+        misc[[i]] = do.call("c", miscTmp)
+      }
+      names(misc) = tmp[[1]]
+    }else{
+      misc = list()
+    }
+  } else {
+    misc = list()
+  }
+  
   #sex
   sex = do.call("c",
                    lapply(popList,
                           function(x) x@sex))
+  
   #nTraits
   nTraits = do.call("c",lapply(popList,
                                function(x) x@nTraits))
   stopifnot(all(nTraits==nTraits[1]))
   nTraits = nTraits[1]
+  
   #nInd
   nInd = do.call("c",lapply(popList,
                             function(x) x@nInd))
+  
   #gv
   gv = do.call("rbind",lapply(popList,
                               function(x) x@gv))
+  
   #pheno
   pheno = do.call("rbind",lapply(popList,
                                  function(x) x@pheno))
+  
   #ebv
   ebv = do.call("c",lapply(popList,
                            function(x) ncol(x@ebv)))
@@ -110,10 +148,11 @@ mergePops = function(popList){
   }else{
     ebv = matrix(NA_real_,nrow=sum(nInd),ncol=0)
   }
+  
   #gxe
   if(nTraits>=1){
     gxe = vector("list",length=nTraits)
-    for(trait in 1:nTraits){
+    for(trait in seq_len(nTraits)){
       if(!is.null(popList[[1]]@gxe[[trait]])){
         tmp = lapply(popList,function(x) x@gxe[[trait]])
         tmp = do.call("c",tmp)
@@ -123,10 +162,13 @@ mergePops = function(popList){
   }else{
     gxe = list()
   }
+  
   #geno
   nBin = as.integer(nLoci%/%8L + (nLoci%%8L > 0L))
   geno = mergeMultGeno(popList,nInd=nInd,nBin=nBin,ploidy=ploidy)
   dim(geno) = NULL # Account for matrix bug in RcppArmadillo
+  
+  #wrap it all up into a Pop
   nInd = sum(nInd)
   return(new("Pop",
              nInd=nInd,
@@ -140,11 +182,11 @@ mergePops = function(popList){
              mother=mother,
              father=father,
              fixEff=fixEff,
+             misc=misc,
+             miscPop=list(),
              nTraits=nTraits,
              gv=gv,
              gxe=gxe,
              pheno=pheno,
-             ebv=ebv,
-             misc=misc,
-             miscPop=list()))
+             ebv=ebv))
 }
